@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.015000';
+$MetaCPAN::Client::Request::VERSION = '1.016000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
@@ -27,7 +27,7 @@ has base_url => (
     lazy    => 1,
     default => sub {
         my $self = shift;
-        return sprintf('http://%s/%s', $self->domain, $self->version);
+        return sprintf('https://%s/%s', $self->domain, $self->version);
     },
 );
 
@@ -232,7 +232,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.015000
+version 1.016000
 
 =head1 ATTRIBUTES
 
@@ -255,13 +255,13 @@ Default: B<v0>.
 =head2 base_url
 
     my $mcpan = MetaCPAN::Client->new(
-        base_url => 'http://localhost:9999/v2',
+        base_url => 'https://localhost:9999/v2',
     );
 
 Instead of overriding the C<base_url>, you should override the C<domain> and
 C<version>. The C<base_url> will be set appropriately automatically.
 
-Default: I<http://$domain/$version>.
+Default: I<https://$domain/$version>.
 
 =head2 ua
 
